@@ -149,7 +149,9 @@ class ViewModeSerializer(ViewModeBase, SerializerFilter, metaclass=SerializerMet
     def component_params(self: "_ViewModeBoundSerializer", output_json: bool = True):
         params = {
             "uuid": self.uuid,
-            "primary_key_name": self.Meta.model._meta.pk.name if self.Meta and self.Meta.model else "id",
+            "primary_key_name": self.Meta.model._meta.pk.name
+            if getattr(self, "Meta", None) and getattr(self.Meta, "model", None)
+            else "id",
             "titles": self.form_titles,
             "columns": [c.as_component_def() for c in self.render_fields.fields],
             "responsive_table_layouts": self.get_responsive_table_layouts_def(),
